@@ -16,6 +16,8 @@ pub mod serde;
 #[derive(Copy, Clone)]
 pub struct String<const L: usize>(pub(crate) [u8; L]);
 
+/// A non-zero sized inlined `String`. It doesn't keep any length, the assumption is
+/// that the capacity is always utilised.
 impl<const L: usize> String<L> {
     pub const fn empty() -> Self {
         Self([b' '; L])
@@ -28,6 +30,17 @@ impl<const L: usize> String<L> {
     pub fn as_str(&self) -> &str {
         &self
     }
+
+    /// Returns whether all bytes in the `String` are empty.
+    pub fn is_empty(&self) -> bool {
+        self.0.iter().all(|&x| x == b' ')
+    }
+
+    /// Returns whether the first byte of the `String` is empty.
+    /// Can be used as a faster version of `is_empty`.
+    pub fn starts_empty(&self) -> bool {
+        self.0[0] == b' '
+    }
 }
 
 impl<const L: usize> Default for String<L> {
@@ -59,11 +72,11 @@ impl<const L: usize> DerefMut for String<L> {
 }
 
 impl<const L: usize> TryFrom<&str> for String<L> {
-    type Error = usize;
+    type Error = crate::error::Error<L>;
 
     fn try_from(s: &str) -> Result<Self, Self::Error> {
         if s.len() != L {
-            return Err(s.len());
+            return Err(s.len().into());
         }
 
         let mut res = Self::empty();
